/* ****************************************************************************
  This file is part of KBabel

  Copyright (C) 1999-2000 by Matthias Kiefer
                            <matthias.kiefer@gmx.de>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

**************************************************************************** */

#include "kbcatalog.h"
#include "headereditor.h"


KBCatalog::KBCatalog(QString configFile, QObject* parent, const char* name) 
         : KBabel::Catalog(parent,name,configFile)
{
   _headerEditor=0;
}


KBCatalog::~KBCatalog()
{
   if(_headerEditor)
      delete _headerEditor;
}

HeaderEditor* KBCatalog::headerEditor()
{
   if(!_headerEditor)
   {
      _headerEditor = new HeaderEditor(this,"_headerEditor");
   }

   return _headerEditor;
}



#include "kbcatalog.moc"
